pub struct GetLayersForNode { /* private fields */ }Expand description
Returns all layers parsed by the rendering engine for the tree scope of a node. Given a DOM element identified by nodeId, getLayersForNode returns the root layer for the nearest ancestor document or shadow root. The layer root contains the full layer tree for the tree scope and their ordering. EXPERIMENTAL: This feature is experimental and may change or be removed.
Implementations