pub struct GetTopLayerElements {}Expand description
Returns NodeIds of current top layer elements. Top layer is rendered closest to the user within a viewport, therefore its elements always appear on top of all other content. EXPERIMENTAL: This feature is experimental and may change or be removed.
Implementations