pub struct ImeSetComposition { /* private fields */ }Expand description
This method sets the current candidate text for IME. Use imeCommitComposition to commit the final text. Use imeSetComposition with empty string as text to cancel composition. EXPERIMENTAL: This feature is experimental and may change or be removed.
Implementations