pub struct EmulateNetworkConditionsByRule { /* private fields */ }Expand description
Activates emulation of network conditions for individual requests using URL match patterns. Unlike the deprecated Network.emulateNetworkConditions this method does not affect navigator state. Use Network.overrideNetworkState to explicitly modify navigator behavior.
EXPERIMENTAL: This feature is experimental and may change or be removed.
Implementations