Module page

Module page 

Structs

AdFrameStatus
Indicates whether a frame has been identified as an ad and why. EXPERIMENTAL: This feature is experimental and may change or be removed.
AdScriptAncestry
Encapsulates the script ancestry and the root script filterlist rule that caused the frame to be labelled as an ad. Only created when ancestryChain is not empty. EXPERIMENTAL: This feature is experimental and may change or be removed.
AdScriptId
Identifies the script which caused a script or frame to be labelled as an ad. EXPERIMENTAL: This feature is experimental and may change or be removed.
AddCompilationCache
Seeds compilation cache for given url. Compilation cache does not survive cross-process navigation. EXPERIMENTAL: This feature is experimental and may change or be removed.
AddScriptToEvaluateOnLoadDeprecated
Deprecated, please use addScriptToEvaluateOnNewDocument instead. EXPERIMENTAL: This feature is experimental and may change or be removed.
AddScriptToEvaluateOnLoadResult
AddScriptToEvaluateOnNewDocument
Evaluates given script in every frame upon creation (before loading frame’s scripts).
AddScriptToEvaluateOnNewDocumentResult
AppManifestError
Error while paring app manifest.
AppManifestParsedProperties
Parsed app manifest properties. EXPERIMENTAL: This feature is experimental and may change or be removed.
BackForwardCacheBlockingDetails
EXPERIMENTAL: This feature is experimental and may change or be removed.
BackForwardCacheNotRestoredExplanation
EXPERIMENTAL: This feature is experimental and may change or be removed.
BackForwardCacheNotRestoredExplanationTree
EXPERIMENTAL: This feature is experimental and may change or be removed.
BackForwardCacheNotUsed
Fired for failed bfcache history navigations if BackForwardCache feature is enabled. Do not assume any ordering with the Page.frameNavigated event. This event is fired only for main-frame history navigation where the document changes (non-same-document navigations), when bfcache navigation fails. EXPERIMENTAL: This feature is experimental and may change or be removed.
BringToFront
Brings page to front (activates tab).
CaptureScreenshot
Capture page screenshot.
CaptureScreenshotResult
CaptureSnapshot
Returns a snapshot of the page as a string. For MHTML format, the serialization includes iframes, shadow DOM, external resources, and element-inline styles. EXPERIMENTAL: This feature is experimental and may change or be removed.
CaptureSnapshotResult
ClearCompilationCache
Clears seeded compilation cache. EXPERIMENTAL: This feature is experimental and may change or be removed.
ClearDeviceMetricsOverrideDeprecated
Clears the overridden device metrics. EXPERIMENTAL: This feature is experimental and may change or be removed.
ClearDeviceOrientationOverrideDeprecated
Clears the overridden Device Orientation. EXPERIMENTAL: This feature is experimental and may change or be removed.
ClearGeolocationOverrideDeprecated
Clears the overridden Geolocation Position and Error.
Close
Tries to close page, running its beforeunload hooks, if any.
CompilationCacheParams
Per-script compilation cache parameters for Page.produceCompilationCache EXPERIMENTAL: This feature is experimental and may change or be removed.
CompilationCacheProduced
Issued for every compilation cache generated. EXPERIMENTAL: This feature is experimental and may change or be removed.
Crash
Crashes renderer on the IO thread, generates minidumps. EXPERIMENTAL: This feature is experimental and may change or be removed.
CreateIsolatedWorld
Creates an isolated world for the given frame.
CreateIsolatedWorldResult
DeleteCookieDeprecated
Deletes browser cookie with given name, domain and path. EXPERIMENTAL: This feature is experimental and may change or be removed.
Disable
Disables page domain notifications.
DocumentOpened
Fired when opening document to write to. EXPERIMENTAL: This feature is experimental and may change or be removed.
DomContentEventFired
DownloadProgressDeprecated
Fired when download makes progress. Last call has |done| == true. Deprecated. Use Browser.downloadProgress instead. EXPERIMENTAL: This feature is experimental and may change or be removed.
DownloadWillBeginDeprecated
Fired when page is about to start a download. Deprecated. Use Browser.downloadWillBegin instead. EXPERIMENTAL: This feature is experimental and may change or be removed.
Enable
Enables page domain notifications.
FileChooserOpened
Emitted only when page.interceptFileChooser is enabled.
FileFilter
EXPERIMENTAL: This feature is experimental and may change or be removed.
FileHandler
EXPERIMENTAL: This feature is experimental and may change or be removed.
FontFamilies
Generic font families collection. EXPERIMENTAL: This feature is experimental and may change or be removed.
FontSizes
Default font sizes. EXPERIMENTAL: This feature is experimental and may change or be removed.
Frame
Information about the Frame on the page.
FrameAttached
Fired when frame has been attached to its parent.
FrameClearedScheduledNavigationDeprecated
Fired when frame no longer has a scheduled navigation.
FrameDetached
Fired when frame has been detached from its parent.
FrameNavigated
Fired once navigation of the frame has completed. Frame is now associated with the new loader.
FrameRequestedNavigation
Fired when a renderer-initiated navigation is requested. Navigation may still be cancelled after the event is issued. EXPERIMENTAL: This feature is experimental and may change or be removed.
FrameResized
EXPERIMENTAL: This feature is experimental and may change or be removed.
FrameResource
Information about the Resource on the page. EXPERIMENTAL: This feature is experimental and may change or be removed.
FrameResourceTree
Information about the Frame hierarchy along with their cached resources. EXPERIMENTAL: This feature is experimental and may change or be removed.
FrameScheduledNavigationDeprecated
Fired when frame schedules a potential navigation.
FrameStartedLoading
Fired when frame has started loading. EXPERIMENTAL: This feature is experimental and may change or be removed.
FrameStartedNavigating
Fired when a navigation starts. This event is fired for both renderer-initiated and browser-initiated navigations. For renderer-initiated navigations, the event is fired after frameRequestedNavigation. Navigation may still be cancelled after the event is issued. Multiple events can be fired for a single navigation, for example, when a same-document navigation becomes a cross-document navigation (such as in the case of a frameset). EXPERIMENTAL: This feature is experimental and may change or be removed.
FrameStoppedLoading
Fired when frame has stopped loading. EXPERIMENTAL: This feature is experimental and may change or be removed.
FrameSubtreeWillBeDetached
Fired before frame subtree is detached. Emitted before any frame of the subtree is actually detached. EXPERIMENTAL: This feature is experimental and may change or be removed.
FrameTree
Information about the Frame hierarchy.
GenerateTestReport
Generates a report for testing. EXPERIMENTAL: This feature is experimental and may change or be removed.
GetAdScriptAncestry
EXPERIMENTAL: This feature is experimental and may change or be removed.
GetAdScriptAncestryResult
GetAnnotatedPageContent
Get the annotated page content for the main frame. This is an experimental command that is subject to change. EXPERIMENTAL: This feature is experimental and may change or be removed.
GetAnnotatedPageContentResult
GetAppId
Returns the unique (PWA) app id. Only returns values if the feature flag ‘WebAppEnableManifestId’ is enabled EXPERIMENTAL: This feature is experimental and may change or be removed.
GetAppIdResult
GetAppManifest
Gets the processed manifest for this current document. This API always waits for the manifest to be loaded. If manifestId is provided, and it does not match the manifest of the current document, this API errors out. If there is not a loaded page, this API errors out immediately.
GetAppManifestResult
GetFrameTree
Returns present frame tree structure.
GetFrameTreeResult
GetInstallabilityErrors
EXPERIMENTAL: This feature is experimental and may change or be removed.
GetInstallabilityErrorsResult
GetLayoutMetrics
Returns metrics relating to the layouting of the page, such as viewport bounds/scale.
GetLayoutMetricsResult
GetManifestIconsDeprecated
Deprecated because it’s not guaranteed that the returned icon is in fact the one used for PWA installation. EXPERIMENTAL: This feature is experimental and may change or be removed.
GetManifestIconsResult
GetNavigationHistory
Returns navigation history for the current page.
GetNavigationHistoryResult
GetOriginTrials
Get Origin Trials on given frame. EXPERIMENTAL: This feature is experimental and may change or be removed.
GetOriginTrialsResult
GetPermissionsPolicyState
Get Permissions Policy state on given frame. EXPERIMENTAL: This feature is experimental and may change or be removed.
GetPermissionsPolicyStateResult
GetResourceContent
Returns content of the given resource. EXPERIMENTAL: This feature is experimental and may change or be removed.
GetResourceContentResult
GetResourceTree
Returns present frame / resource tree structure. EXPERIMENTAL: This feature is experimental and may change or be removed.
GetResourceTreeResult
HandleJavaScriptDialog
Accepts or dismisses a JavaScript initiated dialog (alert, confirm, prompt, or onbeforeunload).
ImageResource
The image definition used in both icon and screenshot. EXPERIMENTAL: This feature is experimental and may change or be removed.
InstallabilityError
The installability error EXPERIMENTAL: This feature is experimental and may change or be removed.
InstallabilityErrorArgument
EXPERIMENTAL: This feature is experimental and may change or be removed.
InterstitialHidden
Fired when interstitial page was hidden
InterstitialShown
Fired when interstitial page was shown
JavascriptDialogClosed
Fired when a JavaScript initiated dialog (alert, confirm, prompt, or onbeforeunload) has been closed.
JavascriptDialogOpening
Fired when a JavaScript initiated dialog (alert, confirm, prompt, or onbeforeunload) is about to open.
LaunchHandler
EXPERIMENTAL: This feature is experimental and may change or be removed.
LayoutViewport
Layout viewport position and dimensions.
LifecycleEvent
Fired for lifecycle events (navigation, load, paint, etc) in the current target (including local frames).
LoadEventFired
Navigate
Navigates current page to the given URL.
NavigateResult
NavigateToHistoryEntry
Navigates current page to the given history entry.
NavigatedWithinDocument
Fired when same-document navigation happens, e.g. due to history API usage or anchor navigation. EXPERIMENTAL: This feature is experimental and may change or be removed.
NavigationEntry
Navigation history entry.
OriginTrial
EXPERIMENTAL: This feature is experimental and may change or be removed.
OriginTrialToken
EXPERIMENTAL: This feature is experimental and may change or be removed.
OriginTrialTokenWithStatus
EXPERIMENTAL: This feature is experimental and may change or be removed.
PermissionsPolicyBlockLocator
EXPERIMENTAL: This feature is experimental and may change or be removed.
PermissionsPolicyFeatureState
EXPERIMENTAL: This feature is experimental and may change or be removed.
PrintToPdf
Print page as PDF.
PrintToPdfResult
ProduceCompilationCache
Requests backend to produce compilation cache for the specified scripts. scripts are appended to the list of scripts for which the cache would be produced. The list may be reset during page navigation. When script with a matching URL is encountered, the cache is optionally produced upon backend discretion, based on internal heuristics. See also: Page.compilationCacheProduced. EXPERIMENTAL: This feature is experimental and may change or be removed.
ProtocolHandler
EXPERIMENTAL: This feature is experimental and may change or be removed.
RelatedApplication
EXPERIMENTAL: This feature is experimental and may change or be removed.
Reload
Reloads given page optionally ignoring the cache.
RemoveScriptToEvaluateOnLoadDeprecated
Deprecated, please use removeScriptToEvaluateOnNewDocument instead. EXPERIMENTAL: This feature is experimental and may change or be removed.
RemoveScriptToEvaluateOnNewDocument
Removes given script from the list.
ResetNavigationHistory
Resets navigation history for the current page.
ScopeExtension
EXPERIMENTAL: This feature is experimental and may change or be removed.
ScreencastFrame
Compressed image data requested by the startScreencast. EXPERIMENTAL: This feature is experimental and may change or be removed.
ScreencastFrameAck
Acknowledges that a screencast frame has been received by the frontend. EXPERIMENTAL: This feature is experimental and may change or be removed.
ScreencastFrameMetadata
Screencast frame metadata. EXPERIMENTAL: This feature is experimental and may change or be removed.
ScreencastVisibilityChanged
Fired when the page with currently enabled screencast was shown or hidden `. EXPERIMENTAL: This feature is experimental and may change or be removed.
Screenshot
EXPERIMENTAL: This feature is experimental and may change or be removed.
ScriptFontFamilies
Font families collection for a script. EXPERIMENTAL: This feature is experimental and may change or be removed.
SearchInResource
Searches for given string in resource content. EXPERIMENTAL: This feature is experimental and may change or be removed.
SearchInResourceResult
SecurityOriginDetails
Additional information about the frame document’s security origin. EXPERIMENTAL: This feature is experimental and may change or be removed.
SetAdBlockingEnabled
Enable Chrome’s experimental ad filter on all sites. EXPERIMENTAL: This feature is experimental and may change or be removed.
SetBypassCsp
Enable page Content Security Policy by-passing.
SetDeviceMetricsOverrideDeprecated
Overrides the values of device screen dimensions (window.screen.width, window.screen.height, window.innerWidth, window.innerHeight, and “device-width”/“device-height”-related CSS media query results). EXPERIMENTAL: This feature is experimental and may change or be removed.
SetDeviceOrientationOverrideDeprecated
Overrides the Device Orientation. EXPERIMENTAL: This feature is experimental and may change or be removed.
SetDocumentContent
Sets given markup as the document’s HTML.
SetDownloadBehaviorDeprecated
Set the behavior when downloading a file. EXPERIMENTAL: This feature is experimental and may change or be removed.
SetFontFamilies
Set generic font families. EXPERIMENTAL: This feature is experimental and may change or be removed.
SetFontSizes
Set default font sizes. EXPERIMENTAL: This feature is experimental and may change or be removed.
SetGeolocationOverrideDeprecated
Overrides the Geolocation Position or Error. Omitting any of the parameters emulates position unavailable.
SetInterceptFileChooserDialog
Intercept file chooser requests and transfer control to protocol clients. When file chooser interception is enabled, native file chooser dialog is not shown. Instead, a protocol event Page.fileChooserOpened is emitted.
SetLifecycleEventsEnabled
Controls whether page will emit lifecycle events.
SetPrerenderingAllowed
Enable/disable prerendering manually. This command is a short-term solution for https://crbug.com/1440085. See https://docs.google.com/document/d/12HVmFxYj5Jc-eJr5OmWsa2bqTJsbgGLKI6ZIyx0_wpA for more details. TODO(https://crbug.com/1440085): Remove this once Puppeteer supports tab targets. EXPERIMENTAL: This feature is experimental and may change or be removed.
SetRphRegistrationMode
Extensions for Custom Handlers API: https://html.spec.whatwg.org/multipage/system-state.html#rph-automation EXPERIMENTAL: This feature is experimental and may change or be removed.
SetSpcTransactionMode
Sets the Secure Payment Confirmation transaction mode. https://w3c.github.io/secure-payment-confirmation/#sctn-automation-set-spc-transaction-mode EXPERIMENTAL: This feature is experimental and may change or be removed.
SetTouchEmulationEnabledDeprecated
Toggles mouse event-based touch event emulation. EXPERIMENTAL: This feature is experimental and may change or be removed.
SetWebLifecycleState
Tries to update the web lifecycle state of the page. It will transition the page to the given state according to: https://github.com/WICG/web-lifecycle/ EXPERIMENTAL: This feature is experimental and may change or be removed.
ShareTarget
EXPERIMENTAL: This feature is experimental and may change or be removed.
Shortcut
EXPERIMENTAL: This feature is experimental and may change or be removed.
StartScreencast
Starts sending each frame using the screencastFrame event. EXPERIMENTAL: This feature is experimental and may change or be removed.
StopLoading
Force the page stop all navigations and pending resource fetches.
StopScreencast
Stops sending each frame in the screencastFrame. EXPERIMENTAL: This feature is experimental and may change or be removed.
Viewport
Viewport for capturing screenshot.
VisualViewport
Visual viewport position, dimensions, and scale.
WaitForDebugger
Pauses page execution. Can be resumed using generic Runtime.runIfWaitingForDebugger. EXPERIMENTAL: This feature is experimental and may change or be removed.
WebAppManifest
EXPERIMENTAL: This feature is experimental and may change or be removed.
WindowOpen
Fired when a new window is going to be opened, via window.open(), link click, form submission, etc.

Enums

AdFrameExplanation
EXPERIMENTAL: This feature is experimental and may change or be removed.
AdFrameType
Indicates whether a frame has been identified as an ad. EXPERIMENTAL: This feature is experimental and may change or be removed.
BackForwardCacheNotRestoredReason
List of not restored reasons for back-forward cache. EXPERIMENTAL: This feature is experimental and may change or be removed.
BackForwardCacheNotRestoredReasonType
Types of not restored reasons for back-forward cache. EXPERIMENTAL: This feature is experimental and may change or be removed.
ClientNavigationDisposition
EXPERIMENTAL: This feature is experimental and may change or be removed.
ClientNavigationReason
EXPERIMENTAL: This feature is experimental and may change or be removed.
CrossOriginIsolatedContextType
Indicates whether the frame is cross-origin isolated and why it is the case. EXPERIMENTAL: This feature is experimental and may change or be removed.
DialogType
Javascript dialog type.
GatedAPIFeatures
EXPERIMENTAL: This feature is experimental and may change or be removed.
NavigationType
The type of a frameNavigated event. EXPERIMENTAL: This feature is experimental and may change or be removed.
OriginTrialStatus
Status for an Origin Trial. EXPERIMENTAL: This feature is experimental and may change or be removed.
OriginTrialTokenStatus
Origin Trial(https://www.chromium.org/blink/origin-trials) support. Status for an Origin Trial token. EXPERIMENTAL: This feature is experimental and may change or be removed.
OriginTrialUsageRestriction
EXPERIMENTAL: This feature is experimental and may change or be removed.
PermissionsPolicyBlockReason
Reason for a permissions policy feature to be disabled. EXPERIMENTAL: This feature is experimental and may change or be removed.
PermissionsPolicyFeature
All Permissions Policy features. This enum should match the one defined in services/network/public/cpp/permissions_policy/permissions_policy_features.json5. LINT.IfChange(PermissionsPolicyFeature) EXPERIMENTAL: This feature is experimental and may change or be removed.
ReferrerPolicy
The referring-policy used for the navigation. EXPERIMENTAL: This feature is experimental and may change or be removed.
SecureContextType
Indicates whether the frame is a secure context and why it is the case. EXPERIMENTAL: This feature is experimental and may change or be removed.
TransitionType
Transition type.

Type Aliases

FrameId
Unique frame identifier.
ScriptIdentifier
Unique script identifier.