AddBinding

Struct AddBinding 

pub struct AddBinding { /* private fields */ }
If executionContextId is empty, adds binding with the given name on the global objects of all inspected contexts, including those created later, bindings survive reloads. Binding function takes exactly one argument, this argument should be string, in case of any other input, function throws an exception. Each binding function call produces Runtime.bindingCalled notification.

Implementations

Source

impl AddBinding

pub fn new(name: impl Into<String>) -> Self

pub fn with_execution_context_id( self, execution_context_id: impl Into<ExecutionContextId>, ) -> Self

pub fn with_execution_context_name( self, execution_context_name: impl Into<String>, ) -> Self