pub struct SendPendingAttributionReports {}Expand description
Sends all pending Attribution Reports immediately, regardless of their scheduled report time. EXPERIMENTAL: This feature is experimental and may change or be removed.
Implementations