Module events

Module events 

CDP events for this domain.

Structs

BackgroundServiceEventReceived
Called with all existing backgroundServiceEvents when enabled, and all new events afterwards if enabled and recording.
RecordingStateChanged
Called when the recording state for the service has been updated.