pub struct GrantPermissions { /* private fields */ }๐Deprecated
Grant specific permissions to the given origin and reject all others. Deprecated. Use setPermission instead. EXPERIMENTAL: This feature is experimental and may change or be removed.
Implementations
Sourceimpl GrantPermissions
impl GrantPermissions
pub fn new(permissions: impl Into<Vec<PermissionType>>) -> Self
pub fn with_origin(self, origin: impl Into<String>) -> Self
pub fn with_browser_context_id( self, browser_context_id: impl Into<BrowserContextID>, ) -> Self