pub struct SetContentsSize { /* private fields */ }Expand description
Set size of the browser contents resizing browser window as necessary. EXPERIMENTAL: This feature is experimental and may change or be removed.
Implementations