Module types

Module types 

CDP type definitions for this domain.

Structs

Bounds
Browser window bounds information EXPERIMENTAL: This feature is experimental and may change or be removed.
Bucket
Chrome histogram bucket. EXPERIMENTAL: This feature is experimental and may change or be removed.
Histogram
Chrome histogram. EXPERIMENTAL: This feature is experimental and may change or be removed.
PermissionDescriptor
Definition of PermissionDescriptor defined in the Permissions API: https://w3c.github.io/permissions/#dom-permissiondescriptor. EXPERIMENTAL: This feature is experimental and may change or be removed.

Enums

BrowserCommandId
Browser command ids used by executeBrowserCommand. EXPERIMENTAL: This feature is experimental and may change or be removed.
PermissionSetting
EXPERIMENTAL: This feature is experimental and may change or be removed.
PermissionType
EXPERIMENTAL: This feature is experimental and may change or be removed.
PrivacySandboxAPI
EXPERIMENTAL: This feature is experimental and may change or be removed.
WindowState
The state of the browser window. EXPERIMENTAL: This feature is experimental and may change or be removed.

Type Aliases

BrowserContextID
EXPERIMENTAL: This feature is experimental and may change or be removed.
WindowID
EXPERIMENTAL: This feature is experimental and may change or be removed.