pub struct Bounds {
pub left: Option<i64>,
pub top: Option<i64>,
pub width: Option<i64>,
pub height: Option<i64>,
pub window_state: Option<WindowState>,
}Expand description
Browser window bounds information EXPERIMENTAL: This feature is experimental and may change or be removed.
Fields
left: Option<i64>The offset from the left edge of the screen to the window in pixels.
top: Option<i64>The offset from the top edge of the screen to the window in pixels.
width: Option<i64>The window width in pixels.
height: Option<i64>The window height in pixels.
window_state: Option<WindowState>The window state. Default to normal.