pub struct SetSinkToUse { /* private fields */ }Expand description
Sets a sink to be used when the web page requests the browser to choose a sink via Presentation API, Remote Playback API, or Cast SDK.
Implementations