Module methods

Module methods 

CDP methods (commands) for this domain.

Structs

ContinueToLocation
Continues execution until specific location is reached.
Disable
Disables debugger for given page.
DisassembleWasmModule
EXPERIMENTAL: This feature is experimental and may change or be removed.
Enable
Enables debugger for the given page. Clients should not assume that the debugging has been enabled until the result for this command is received.
EvaluateOnCallFrame
Evaluates expression on a given call frame.
GetPossibleBreakpoints
Returns possible locations for breakpoint. scriptId in start and end range locations should be the same.
GetScriptSource
Returns source for the script with given id.
GetStackTrace
Returns stack trace with given stackTraceId. EXPERIMENTAL: This feature is experimental and may change or be removed.
GetWasmBytecodeDeprecated
This command is deprecated. Use getScriptSource instead.
NextWasmDisassemblyChunk
Disassemble the next chunk of lines for the module corresponding to the stream. If disassembly is complete, this API will invalidate the streamId and return an empty chunk. Any subsequent calls for the now invalid stream will return errors. EXPERIMENTAL: This feature is experimental and may change or be removed.
Pause
Stops on the next JavaScript statement.
PauseOnAsyncCallDeprecated
EXPERIMENTAL: This feature is experimental and may change or be removed.
RemoveBreakpoint
Removes JavaScript breakpoint.
RestartFrame
Restarts particular call frame from the beginning. The old, deprecated behavior of restartFrame is to stay paused and allow further CDP commands after a restart was scheduled. This can cause problems with restarting, so we now continue execution immediatly after it has been scheduled until we reach the beginning of the restarted frame. To stay back-wards compatible, restartFrame now expects a mode parameter to be present. If the mode parameter is missing, restartFrame errors out. The various return values are deprecated and callFrames is always empty. Use the call frames from the Debugger#paused events instead, that fires once V8 pauses at the beginning of the restarted function.
Resume
Resumes JavaScript execution.
SearchInContent
Searches for given string in script content.
SetAsyncCallStackDepth
Enables or disables async call stacks tracking.
SetBlackboxExecutionContexts
Replace previous blackbox execution contexts with passed ones. Forces backend to skip stepping/pausing in scripts in these execution contexts. VM will try to leave blackboxed script by performing ‘step in’ several times, finally resorting to ‘step out’ if unsuccessful. EXPERIMENTAL: This feature is experimental and may change or be removed.
SetBlackboxPatterns
Replace previous blackbox patterns with passed ones. Forces backend to skip stepping/pausing in scripts with url matching one of the patterns. VM will try to leave blackboxed script by performing ‘step in’ several times, finally resorting to ‘step out’ if unsuccessful. EXPERIMENTAL: This feature is experimental and may change or be removed.
SetBlackboxedRanges
Makes backend skip steps in the script in blackboxed ranges. VM will try leave blacklisted scripts by performing ‘step in’ several times, finally resorting to ‘step out’ if unsuccessful. Positions array contains positions where blackbox state is changed. First interval isn’t blackboxed. Array should be sorted. EXPERIMENTAL: This feature is experimental and may change or be removed.
SetBreakpoint
Sets JavaScript breakpoint at a given location.
SetBreakpointByUrl
Sets JavaScript breakpoint at given location specified either by URL or URL regex. Once this command is issued, all existing parsed scripts will have breakpoints resolved and returned in locations property. Further matching script parsing will result in subsequent breakpointResolved events issued. This logical breakpoint will survive page reloads.
SetBreakpointOnFunctionCall
Sets JavaScript breakpoint before each call to the given function. If another function was created from the same source as a given one, calling it will also trigger the breakpoint. EXPERIMENTAL: This feature is experimental and may change or be removed.
SetBreakpointsActive
Activates / deactivates all breakpoints on the page.
SetInstrumentationBreakpoint
Sets instrumentation breakpoint.
SetPauseOnExceptions
Defines pause on exceptions state. Can be set to stop on all exceptions, uncaught exceptions, or caught exceptions, no exceptions. Initial pause on exceptions state is none.
SetReturnValue
Changes return value in top frame. Available only at return break position. EXPERIMENTAL: This feature is experimental and may change or be removed.
SetScriptSource
Edits JavaScript source live. In general, functions that are currently on the stack can not be edited with a single exception: If the edited function is the top-most stack frame and that is the only activation of that function on the stack. In this case the live edit will be successful and a Debugger.restartFrame for the top-most function is automatically triggered.
SetSkipAllPauses
Makes page not interrupt on any pauses (breakpoint, exception, dom exception etc).
SetVariableValue
Changes value of variable in a callframe. Object-based scopes are not supported and must be mutated manually.
StepInto
Steps into the function call.
StepOut
Steps out of the function call.
StepOver
Steps over the statement.