pub struct Enable { /* private fields */ }Expand description
Enables debugger for the given page. Clients should not assume that the debugging has been enabled until the result for this command is received.
Implementations