pub struct GetRelayoutBoundary { /* private fields */ }Expand description
Returns the id of the nearest ancestor that is a relayout boundary. EXPERIMENTAL: This feature is experimental and may change or be removed.
Implementations