Module methods

Module methods 

CDP methods (commands) for this domain.

Structs

CaptureSnapshot
Returns a document snapshot, including the full DOM tree of the root node (including iframes, template contents, and imported documents) in a flattened array, as well as layout and white-listed computed style information for the nodes. Shadow DOM in the returned DOM tree is flattened.
Disable
Disables DOM snapshot agent for the given page.
Enable
Enables DOM snapshot agent for the given page.
GetSnapshotDeprecated
Returns a document snapshot, including the full DOM tree of the root node (including iframes, template contents, and imported documents) in a flattened array, as well as layout and white-listed computed style information for the nodes. Shadow DOM in the returned DOM tree is flattened.