pub struct SetStorageItems { /* private fields */ }Expand description
Sets values in extension storage in the given storageArea. The provided values will be merged with existing values in the storage area.
Implementations