pub struct InsertText { /* private fields */ }Expand description
This method emulates inserting text that doesn’t come from a key press, for example an emoji keyboard or an IME. EXPERIMENTAL: This feature is experimental and may change or be removed.
Implementations