pub struct SetInterceptDrags { /* private fields */ }Expand description
Prevents default drag and drop behavior and instead emits Input.dragIntercepted events. Drag and drop behavior can be directly controlled via Input.dispatchDragEvent.
EXPERIMENTAL: This feature is experimental and may change or be removed.
Implementations