RequestIntercepted

Struct RequestIntercepted 

pub struct RequestIntercepted {
    pub interception_id: InterceptionId,
    pub request: Request,
    pub frame_id: FrameId,
    pub resource_type: ResourceType,
    pub is_navigation_request: bool,
    pub is_download: Option<bool>,
    pub redirect_url: Option<String>,
    pub auth_challenge: Option<AuthChallenge>,
    pub response_error_reason: Option<ErrorReason>,
    pub response_status_code: Option<i64>,
    pub response_headers: Option<Headers>,
    pub request_id: Option<RequestId>,
}
👎Deprecated
Details of an intercepted HTTP request, which must be either allowed, blocked, modified or mocked. Deprecated, use Fetch.requestPaused instead. EXPERIMENTAL: This feature is experimental and may change or be removed.

Fields

interception_id: InterceptionId
👎Deprecated

Each request the page makes will have a unique id, however if any redirects are encountered while processing that fetch, they will be reported with the same id as the original fetch. Likewise if HTTP authentication is needed then the same fetch id will be used.

request: Request
👎Deprecated
frame_id: FrameId
👎Deprecated

The id of the frame that initiated the request.

resource_type: ResourceType
👎Deprecated

How the requested resource will be used.

is_navigation_request: bool
👎Deprecated

Whether this is a navigation request, which can abort the navigation completely.

is_download: Option<bool>
👎Deprecated

Set if the request is a navigation that will result in a download. Only present after response is received from the server (i.e. HeadersReceived stage).

redirect_url: Option<String>
👎Deprecated

Redirect location, only sent if a redirect was intercepted.

auth_challenge: Option<AuthChallenge>
👎Deprecated

Details of the Authorization Challenge encountered. If this is set then continueInterceptedRequest must contain an authChallengeResponse.

response_error_reason: Option<ErrorReason>
👎Deprecated

Response error if intercepted at response stage or if redirect occurred while intercepting request.

response_status_code: Option<i64>
👎Deprecated

Response code if intercepted at response stage or if redirect occurred while intercepting request or auth retry occurred.

response_headers: Option<Headers>
👎Deprecated

Response headers if intercepted at the response stage or if redirect occurred while intercepting request or auth retry occurred.

request_id: Option<RequestId>
👎Deprecated

If the intercepted request had a corresponding requestWillBeSent event fired for it, then this requestId will be the same as the requestId present in the requestWillBeSent event.

Implementations

Source

impl RequestIntercepted

pub fn subscribe(cdp: &CDP) -> Pin<Box<dyn Stream<Item = Self> + Send>>