pub struct ContinueInterceptedRequest { /* private fields */ }๐Deprecated
Response to Network.requestIntercepted which either modifies the request to continue with any modifications, or blocks it, or completes it with the provided response bytes. If a network fetch occurs as a result which encounters a redirect an additional Network.requestIntercepted event will be sent with the same InterceptionId. Deprecated, use Fetch.continueRequest, Fetch.fulfillRequest and Fetch.failRequest instead. EXPERIMENTAL: This feature is experimental and may change or be removed.
Implementations
Sourceimpl ContinueInterceptedRequest
impl ContinueInterceptedRequest
pub fn new(interception_id: impl Into<InterceptionId>) -> Self
pub fn with_error_reason(self, error_reason: impl Into<ErrorReason>) -> Self
pub fn with_raw_response(self, raw_response: impl Into<String>) -> Self
pub fn with_url(self, url: impl Into<String>) -> Self
pub fn with_method(self, method: impl Into<String>) -> Self
pub fn with_post_data(self, post_data: impl Into<String>) -> Self
pub fn with_headers(self, headers: impl Into<Headers>) -> Self
pub fn with_auth_challenge_response( self, auth_challenge_response: impl Into<AuthChallengeResponse>, ) -> Self