pub struct EnableDeviceBoundSessions { /* private fields */ }Expand description
Sets up tracking device bound sessions and fetching of initial set of sessions. EXPERIMENTAL: This feature is experimental and may change or be removed.
Implementations