pub struct GetResponseBodyForInterception { /* private fields */ }Expand description
Returns content served for the given currently intercepted request. EXPERIMENTAL: This feature is experimental and may change or be removed.
Implementations
Sourceimpl GetResponseBodyForInterception
impl GetResponseBodyForInterception
pub fn new(interception_id: impl Into<InterceptionId>) -> Self