pub struct SetRequestInterception { /* private fields */ }๐Deprecated
Sets the requests to intercept that match the provided patterns and optionally resource types. Deprecated, please use Fetch.enable instead. EXPERIMENTAL: This feature is experimental and may change or be removed.
Implementations
Sourceimpl SetRequestInterception
impl SetRequestInterception
pub fn new(patterns: impl Into<Vec<RequestPattern>>) -> Self