pub struct BindingCalled {
pub name: String,
pub payload: String,
pub execution_context_id: ExecutionContextId,
}Expand description
Notification is issued every time when binding is called. EXPERIMENTAL: This feature is experimental and may change or be removed.
Fields
name: Stringpayload: Stringexecution_context_id: ExecutionContextIdIdentifier of the context where the call was made.
Implementations