pub struct RemoteObject {
pub type_: String,
pub subtype: Option<String>,
pub class_name: Option<String>,
pub value: Option<Value>,
pub unserializable_value: Option<UnserializableValue>,
pub description: Option<String>,
pub deep_serialized_value: Option<DeepSerializedValue>,
pub object_id: Option<RemoteObjectId>,
pub preview: Option<ObjectPreview>,
pub custom_preview: Option<CustomPreview>,
}Expand description
Mirror object referencing original JavaScript object.
Fields
type_: StringObject type.
subtype: Option<String>Object subtype hint. Specified for object type values only. NOTE: If you change anything here, make sure to also update subtype in ObjectPreview and PropertyPreview below.
class_name: Option<String>Object class (constructor) name. Specified for object type values only.
value: Option<Value>Remote object value in case of primitive values or JSON values (if it was requested).
unserializable_value: Option<UnserializableValue>Primitive value which can not be JSON-stringified does not have value, but gets this property.
description: Option<String>String representation of the object.
deep_serialized_value: Option<DeepSerializedValue>Deep serialized value. EXPERIMENTAL
object_id: Option<RemoteObjectId>Unique object identifier (for non-primitive values).
preview: Option<ObjectPreview>Preview containing abbreviated property values. Specified for object type values only.
EXPERIMENTAL
custom_preview: Option<CustomPreview>EXPERIMENTAL