pub struct GetStorageKey { /* private fields */ }Expand description
Returns storage key for the given frame. If no frame ID is provided, the storage key of the target executing this command is returned. EXPERIMENTAL: This feature is experimental and may change or be removed.
Implementations
Sourceimpl GetStorageKey
impl GetStorageKey