Module types

Module types 

CDP type definitions for this domain.

Structs

GPUDevice
Describes a single graphics processor (GPU).
GPUInfo
Provides information about the GPU(s) on the system.
ProcessInfo
Represents process info.
Size
Describes the width and height dimensions of an entity.
VideoDecodeAcceleratorCapability
Describes a supported video decoding profile with its associated minimum and maximum resolutions.
VideoEncodeAcceleratorCapability
Describes a supported video encoding profile with its associated maximum resolution and maximum framerate.

Enums

ImageType
Image format of a given image.
SubsamplingFormat
YUV subsampling type of the pixels of a given image.