pub struct QueryAxTree { /* private fields */ }Expand description
Query a DOM node’s accessibility subtree for accessible name and role. This command computes the name and role for all nodes in the subtree, including those that are ignored for accessibility, and returns those that match the specified name and role. If no DOM node is specified, or the DOM node does not exist, the command returns an error. If neither accessibleName or role is specified, it returns all the accessibility nodes in the subtree.
EXPERIMENTAL: This feature is experimental and may change or be removed.
Implementations
Sourceimpl QueryAxTree
impl QueryAxTree
pub fn new() -> Self
pub fn with_node_id(self, node_id: impl Into<NodeId>) -> Self
pub fn with_backend_node_id( self, backend_node_id: impl Into<BackendNodeId>, ) -> Self
pub fn with_object_id(self, object_id: impl Into<RemoteObjectId>) -> Self
pub fn with_accessible_name(self, accessible_name: impl Into<String>) -> Self
pub fn with_role(self, role: impl Into<String>) -> Self