Encapsulates the script ancestry and the root script filterlist rule that caused the frame to be labelled as an ad. Only created when ancestryChain is not empty.
EXPERIMENTAL: This feature is experimental and may change or be removed.
Seeds compilation cache for given url. Compilation cache does not survive cross-process navigation.
EXPERIMENTAL: This feature is experimental and may change or be removed.
Fired for failed bfcache history navigations if BackForwardCache feature is enabled. Do not assume any ordering with the Page.frameNavigated event. This event is fired only for main-frame history navigation where the document changes (non-same-document navigations), when bfcache navigation fails.
EXPERIMENTAL: This feature is experimental and may change or be removed.
Returns a snapshot of the page as a string. For MHTML format, the serialization includes iframes, shadow DOM, external resources, and element-inline styles.
EXPERIMENTAL: This feature is experimental and may change or be removed.
Fired when download makes progress. Last call has |done| == true. Deprecated. Use Browser.downloadProgress instead.
EXPERIMENTAL: This feature is experimental and may change or be removed.
Fired when page is about to start a download. Deprecated. Use Browser.downloadWillBegin instead.
EXPERIMENTAL: This feature is experimental and may change or be removed.
Fired when a renderer-initiated navigation is requested. Navigation may still be cancelled after the event is issued.
EXPERIMENTAL: This feature is experimental and may change or be removed.
Fired when a navigation starts. This event is fired for both renderer-initiated and browser-initiated navigations. For renderer-initiated navigations, the event is fired after frameRequestedNavigation. Navigation may still be cancelled after the event is issued. Multiple events can be fired for a single navigation, for example, when a same-document navigation becomes a cross-document navigation (such as in the case of a frameset).
EXPERIMENTAL: This feature is experimental and may change or be removed.
Fired before frame subtree is detached. Emitted before any frame of the subtree is actually detached.
EXPERIMENTAL: This feature is experimental and may change or be removed.
Get the annotated page content for the main frame. This is an experimental command that is subject to change.
EXPERIMENTAL: This feature is experimental and may change or be removed.
Returns the unique (PWA) app id. Only returns values if the feature flag ‘WebAppEnableManifestId’ is enabled
EXPERIMENTAL: This feature is experimental and may change or be removed.
Gets the processed manifest for this current document. This API always waits for the manifest to be loaded. If manifestId is provided, and it does not match the manifest of the current document, this API errors out. If there is not a loaded page, this API errors out immediately.
Deprecated because it’s not guaranteed that the returned icon is in fact the one used for PWA installation.
EXPERIMENTAL: This feature is experimental and may change or be removed.
Fired when same-document navigation happens, e.g. due to history API usage or anchor navigation.
EXPERIMENTAL: This feature is experimental and may change or be removed.
Requests backend to produce compilation cache for the specified scripts. scripts are appended to the list of scripts for which the cache would be produced. The list may be reset during page navigation. When script with a matching URL is encountered, the cache is optionally produced upon backend discretion, based on internal heuristics. See also: Page.compilationCacheProduced.
EXPERIMENTAL: This feature is experimental and may change or be removed.
Overrides the values of device screen dimensions (window.screen.width, window.screen.height, window.innerWidth, window.innerHeight, and “device-width”/“device-height”-related CSS media query results).
EXPERIMENTAL: This feature is experimental and may change or be removed.
Intercept file chooser requests and transfer control to protocol clients. When file chooser interception is enabled, native file chooser dialog is not shown. Instead, a protocol event Page.fileChooserOpened is emitted.
Enable/disable prerendering manually. This command is a short-term solution for https://crbug.com/1440085. See https://docs.google.com/document/d/12HVmFxYj5Jc-eJr5OmWsa2bqTJsbgGLKI6ZIyx0_wpA for more details. TODO(https://crbug.com/1440085): Remove this once Puppeteer supports tab targets.
EXPERIMENTAL: This feature is experimental and may change or be removed.
Extensions for Custom Handlers API: https://html.spec.whatwg.org/multipage/system-state.html#rph-automation
EXPERIMENTAL: This feature is experimental and may change or be removed.
Sets the Secure Payment Confirmation transaction mode. https://w3c.github.io/secure-payment-confirmation/#sctn-automation-set-spc-transaction-mode
EXPERIMENTAL: This feature is experimental and may change or be removed.
Tries to update the web lifecycle state of the page. It will transition the page to the given state according to: https://github.com/WICG/web-lifecycle/
EXPERIMENTAL: This feature is experimental and may change or be removed.
Pauses page execution. Can be resumed using generic Runtime.runIfWaitingForDebugger.
EXPERIMENTAL: This feature is experimental and may change or be removed.
Origin Trial(https://www.chromium.org/blink/origin-trials) support. Status for an Origin Trial token.
EXPERIMENTAL: This feature is experimental and may change or be removed.
All Permissions Policy features. This enum should match the one defined in services/network/public/cpp/permissions_policy/permissions_policy_features.json5. LINT.IfChange(PermissionsPolicyFeature)
EXPERIMENTAL: This feature is experimental and may change or be removed.