CDP type definitions for this domain.
Structs
- Bounds
- Browser window bounds information EXPERIMENTAL: This feature is experimental and may change or be removed.
- Bucket
- Chrome histogram bucket. EXPERIMENTAL: This feature is experimental and may change or be removed.
- Histogram
- Chrome histogram. EXPERIMENTAL: This feature is experimental and may change or be removed.
- Permission
Descriptor - Definition of PermissionDescriptor defined in the Permissions API: https://w3c.github.io/permissions/#dom-permissiondescriptor. EXPERIMENTAL: This feature is experimental and may change or be removed.
Enums
- Browser
Command Id - Browser command ids used by executeBrowserCommand. EXPERIMENTAL: This feature is experimental and may change or be removed.
- Permission
Setting - EXPERIMENTAL: This feature is experimental and may change or be removed.
- Permission
Type - EXPERIMENTAL: This feature is experimental and may change or be removed.
- Privacy
SandboxAPI - EXPERIMENTAL: This feature is experimental and may change or be removed.
- Window
State - The state of the browser window. EXPERIMENTAL: This feature is experimental and may change or be removed.
Type Aliases
- Browser
ContextID - EXPERIMENTAL: This feature is experimental and may change or be removed.
- WindowID
- EXPERIMENTAL: This feature is experimental and may change or be removed.