CDP methods (commands) for this domain.
Structs
- Continue
ToLocation - Continues execution until specific location is reached.
- Disable
- Disables debugger for given page.
- Disassemble
Wasm Module - EXPERIMENTAL: This feature is experimental and may change or be removed.
- Enable
- Enables debugger for the given page. Clients should not assume that the debugging has been enabled until the result for this command is received.
- Evaluate
OnCall Frame - Evaluates expression on a given call frame.
- GetPossible
Breakpoints - Returns possible locations for breakpoint. scriptId in start and end range locations should be the same.
- GetScript
Source - Returns source for the script with given id.
- GetStack
Trace - Returns stack trace with given
stackTraceId. EXPERIMENTAL: This feature is experimental and may change or be removed. - GetWasm
Bytecode Deprecated - This command is deprecated. Use getScriptSource instead.
- Next
Wasm Disassembly Chunk - Disassemble the next chunk of lines for the module corresponding to the stream. If disassembly is complete, this API will invalidate the streamId and return an empty chunk. Any subsequent calls for the now invalid stream will return errors. EXPERIMENTAL: This feature is experimental and may change or be removed.
- Pause
- Stops on the next JavaScript statement.
- Pause
OnAsync Call Deprecated - EXPERIMENTAL: This feature is experimental and may change or be removed.
- Remove
Breakpoint - Removes JavaScript breakpoint.
- Restart
Frame - Restarts particular call frame from the beginning. The old, deprecated behavior of
restartFrameis to stay paused and allow further CDP commands after a restart was scheduled. This can cause problems with restarting, so we now continue execution immediatly after it has been scheduled until we reach the beginning of the restarted frame. To stay back-wards compatible,restartFramenow expects amodeparameter to be present. If themodeparameter is missing,restartFrameerrors out. The various return values are deprecated andcallFramesis always empty. Use the call frames from theDebugger#pausedevents instead, that fires once V8 pauses at the beginning of the restarted function. - Resume
- Resumes JavaScript execution.
- Search
InContent - Searches for given string in script content.
- SetAsync
Call Stack Depth - Enables or disables async call stacks tracking.
- SetBlackbox
Execution Contexts - Replace previous blackbox execution contexts with passed ones. Forces backend to skip stepping/pausing in scripts in these execution contexts. VM will try to leave blackboxed script by performing ‘step in’ several times, finally resorting to ‘step out’ if unsuccessful. EXPERIMENTAL: This feature is experimental and may change or be removed.
- SetBlackbox
Patterns - Replace previous blackbox patterns with passed ones. Forces backend to skip stepping/pausing in scripts with url matching one of the patterns. VM will try to leave blackboxed script by performing ‘step in’ several times, finally resorting to ‘step out’ if unsuccessful. EXPERIMENTAL: This feature is experimental and may change or be removed.
- SetBlackboxed
Ranges - Makes backend skip steps in the script in blackboxed ranges. VM will try leave blacklisted scripts by performing ‘step in’ several times, finally resorting to ‘step out’ if unsuccessful. Positions array contains positions where blackbox state is changed. First interval isn’t blackboxed. Array should be sorted. EXPERIMENTAL: This feature is experimental and may change or be removed.
- SetBreakpoint
- Sets JavaScript breakpoint at a given location.
- SetBreakpoint
ByUrl - Sets JavaScript breakpoint at given location specified either by URL or URL regex. Once this command is issued, all existing parsed scripts will have breakpoints resolved and returned in
locationsproperty. Further matching script parsing will result in subsequentbreakpointResolvedevents issued. This logical breakpoint will survive page reloads. - SetBreakpoint
OnFunction Call - Sets JavaScript breakpoint before each call to the given function. If another function was created from the same source as a given one, calling it will also trigger the breakpoint. EXPERIMENTAL: This feature is experimental and may change or be removed.
- SetBreakpoints
Active - Activates / deactivates all breakpoints on the page.
- SetInstrumentation
Breakpoint - Sets instrumentation breakpoint.
- SetPause
OnExceptions - Defines pause on exceptions state. Can be set to stop on all exceptions, uncaught exceptions, or caught exceptions, no exceptions. Initial pause on exceptions state is
none. - SetReturn
Value - Changes return value in top frame. Available only at return break position. EXPERIMENTAL: This feature is experimental and may change or be removed.
- SetScript
Source - Edits JavaScript source live. In general, functions that are currently on the stack can not be edited with a single exception: If the edited function is the top-most stack frame and that is the only activation of that function on the stack. In this case the live edit will be successful and a
Debugger.restartFramefor the top-most function is automatically triggered. - SetSkip
AllPauses - Makes page not interrupt on any pauses (breakpoint, exception, dom exception etc).
- SetVariable
Value - Changes value of variable in a callframe. Object-based scopes are not supported and must be mutated manually.
- Step
Into - Steps into the function call.
- StepOut
- Steps out of the function call.
- Step
Over - Steps over the statement.